@@ -19,35 +19,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <stdio.h>
-#include <stdarg.h>
-#include <stdlib.h>
-#if HAVE_STRING_H
-# if !STDC_HEADERS && HAVE_MEMORY_H
-#  include <memory.h>
-# endif
-# include <string.h>
-#endif
-#if HAVE_STRINGS_H
-# include <strings.h>
-#endif
-#if HAVE_INTTYPES_H
-# include <inttypes.h>
-#else
-# if HAVE_STDINT_H
-#  include <stdint.h>
-# endif
-#endif
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
-#include <stringprep.h>
-#include <stringprep_generic.h>
+#include "internal.h"
 
 static int debug = 0;
 static int error_count = 0;
@@ -74,13 +46,13 @@ escapeprint (char *str, int len)
   printf ("\t ;; `");
   for (i = 0; i < len; i++)
     {
-      str[i] = str[i] & 0xFF;
-      if ((str[i] >= 'A' && str[i] <= 'Z') ||
-	  (str[i] >= 'a' && str[i] <= 'z') ||
-	  (str[i] >= '0' && str[i] <= '9') || str[i] == '.')
-	printf ("%c", str[i]);
+      if (((str[i] & 0xFF) >= 'A' && (str[i] & 0xFF) <= 'Z') ||
+	  ((str[i] & 0xFF) >= 'a' && (str[i] & 0xFF) <= 'z') ||
+	  ((str[i] & 0xFF) >= '0' && (str[i] & 0xFF) <= '9')
+	  || (str[i] & 0xFF) == '.')
+	printf ("%c", (str[i] & 0xFF));
       else
-	printf ("\\x%02x", str[i]);
+	printf ("\\x%02x", (str[i] & 0xFF));
     }
   printf ("' (length %d bytes)\n", len);
 }
@@ -93,8 +65,7 @@ hexprint (char *str, int len)
   printf ("\t ;; ");
   for (i = 0; i < len; i++)
     {
-      str[i] = str[i] & 0xFF;
-      printf ("%02x ", str[i]);
+      printf ("%02x ", (str[i] & 0xFF));
       if ((i + 1) % 8 == 0)
 	printf (" ");
       if ((i + 1) % 16 == 0 && i + 1 < len)
@@ -110,15 +81,14 @@ binprint (char *str, int len)
   printf ("\t ;; ");
   for (i = 0; i < len; i++)
     {
-      str[i] = str[i] & 0xFF;
       printf ("%d%d%d%d%d%d%d%d ",
-	      str[i] & 0x80 ? 1 : 0,
-	      str[i] & 0x40 ? 1 : 0,
-	      str[i] & 0x20 ? 1 : 0,
-	      str[i] & 0x10 ? 1 : 0,
-	      str[i] & 0x08 ? 1 : 0,
-	      str[i] & 0x04 ? 1 : 0,
-	      str[i] & 0x02 ? 1 : 0, str[i] & 0x01 ? 1 : 0);
+	      (str[i] & 0xFF) & 0x80 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x40 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x20 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x10 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x08 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x04 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x02 ? 1 : 0, (str[i] & 0xFF) & 0x01 ? 1 : 0);
       if ((i + 1) % 3 == 0)
 	printf (" ");
       if ((i + 1) % 6 == 0 && i + 1 < len)
@@ -132,6 +102,7 @@ struct stringprep
   int flags;
   char *out;
   stringprep_profile *profile;
+  int rc;
 }
 strprep[] =
 {
@@ -149,6 +120,22 @@ strprep[] =
   ,
   {
   "\xC2\xAA", 0, "\x61", stringprep_generic}
+  ,
+  /* unassigned code point 0221: */
+  {
+    "\xC8\xA1", 0, "\xC8\xA1", stringprep_generic}
+  ,
+  /* unassigned code point 0221: */
+  {
+    "\xC8\xA1", STRINGPREP_NO_UNASSIGNED, NULL, stringprep_generic, STRINGPREP_CONTAINS_UNASSIGNED}
+  ,
+  /* unassigned code point 0236: */
+  {
+    "\xC8\xB6", 0, "\xC8\xB6", stringprep_generic}
+  ,
+  /* unassigned code point 0236: */
+  {
+    "\xC8\xB6", STRINGPREP_NO_UNASSIGNED, NULL, stringprep_generic, STRINGPREP_CONTAINS_UNASSIGNED}
 };
 
 int
@@ -186,7 +173,7 @@ main (int argc, char *argv[])
       strcpy (p, strprep[i].in);
 
       rc = stringprep (p, BUFSIZ, strprep[i].flags, strprep[i].profile);
-      if (rc != STRINGPREP_OK)
+      if (rc != strprep[i].rc)
 	{
 	  fail ("stringprep() entry %d failed: %d\n", i, rc);
 	  continue;
@@ -194,6 +181,8 @@ main (int argc, char *argv[])
 
       if (debug)
 	{
+	  printf ("flags: %d\n", strprep[i].flags);
+
 	  printf ("in:\n");
 	  escapeprint (strprep[i].in, strlen (strprep[i].in));
 	  hexprint (strprep[i].in, strlen (strprep[i].in));
@@ -201,27 +190,35 @@ main (int argc, char *argv[])
 	  binprint (strprep[i].in, strlen (strprep[i].in));
 	  puts ("");
 
-	  printf ("out:\n");
-	  escapeprint (p, strlen (p));
-	  hexprint (p, strlen (p));
-	  puts ("");
-	  binprint (p, strlen (p));
-	  puts ("");
+	  if (rc == STRINGPREP_OK)
+	    {
+	      printf ("out:\n");
+	      escapeprint (p, strlen (p));
+	      hexprint (p, strlen (p));
+	      puts ("");
+	      binprint (p, strlen (p));
+	      puts ("");
 
-	  printf ("expected out:\n");
-	  escapeprint (strprep[i].out, strlen (strprep[i].out));
-	  hexprint (strprep[i].out, strlen (strprep[i].out));
-	  puts ("");
-	  binprint (strprep[i].out, strlen (strprep[i].out));
-	  puts ("");
+	      printf ("expected out:\n");
+	      escapeprint (strprep[i].out, strlen (strprep[i].out));
+	      hexprint (strprep[i].out, strlen (strprep[i].out));
+	      puts ("");
+	      binprint (strprep[i].out, strlen (strprep[i].out));
+	      puts ("");
+	    }
+	  else
+	    printf("returned %d expected %d\n", rc, strprep[i].rc);
 	}
 
-      if (strlen (strprep[i].out) != strlen (p) ||
-	  memcmp (strprep[i].out, p, strlen (p)) != 0)
+      if (rc == STRINGPREP_OK)
 	{
-	  fail ("stringprep() entry %d failed\n", i);
-	  if (debug)
-	    printf ("ERROR\n");
+	  if (strlen (strprep[i].out) != strlen (p) ||
+	      memcmp (strprep[i].out, p, strlen (p)) != 0)
+	    {
+	      fail ("stringprep() entry %d failed\n", i);
+	      if (debug)
+		printf ("ERROR\n");
+	    }
 	}
       else if (debug)
 	printf ("OK\n");
